pub struct Link<I = Instant> { /* private fields */ }Expand description
An in-process link between two stacks.
Implementations
Sourceimpl<I> Link<I>
impl<I> Link<I>
Sourcepub fn new(seed: u64, faults: Faults) -> Self
pub fn new(seed: u64, faults: Faults) -> Self
A link with these faults, replaying the same trace for the same seed.
Sourcepub fn send(&mut self, from: Side, bytes: Bytes, now: I)
pub fn send(&mut self, from: Side, bytes: Bytes, now: I)
Hand a datagram to the link, to arrive at some point at or after now.
Sourcepub fn take_due(&mut self, now: I) -> Vec<Delivery>
pub fn take_due(&mut self, now: I) -> Vec<Delivery>
Everything that has arrived at or before now, in arrival order.
Sourcepub fn next_arrival(&self) -> Option<I>
pub fn next_arrival(&self) -> Option<I>
When the next datagram arrives, if any is in flight.