#[non_exhaustive]pub enum PeerError {
Bind(String),
NoSession,
SessionEnded,
NotObserved {
what: String,
},
}Expand description
Everything that can go wrong driving the peer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bind(String)
The loopback listener could not be bound.
NoSession
No client is connected, so there is nothing to send the directive to.
SessionEnded
The connection ended before the directive could be performed.
NotObserved
The record never satisfied the condition within OBSERVATION_BOUND.